Project — Airflow Documentation

# Project

## History

Airflow was started in October 2014 by Maxime Beauchemin at Airbnb. It was open source from the very first commit and officially brought under the Airbnb Github and announced in June 2015.

The project joined the Apache Software Foundation’s incubation program in March 2016.

## Committers

- @mistercrunch (Maxime “Max” Beauchemin)
- @r39132 (Siddharth “Sid” Anand)
- @criccomini (Chris Riccomini)
- @bolkedebruin (Bolke de Bruin)
- @artwr (Arthur Wiedmer)
- @jlowin (Jeremiah Lowin)
- @patrickleotardif (Patrick Leo Tardif)
- @aoen (Dan Davydov)
- @syvineckruyk (Steven Yvinec-Kruyk)

For the full list of contributors, take a look at Airflow’s Github Contributor page:

## Resources & links

- Airflow’s official documentation
- Mailing list (send emails to `dev-subscribe@airflow.incubator.apache.org` and/or `commits-subscribe@airflow.incubator.apache.org` to subscribe to each)
- Issues on Apache’s Jira
- Gitter (chat) Channel
- More resources and links to Airflow related content on the Wiki

## Roadmap

Please refer to the Roadmap on the wiki